Plug sources as trust-aware value objects: a tools.deps coord classified into a family with its mutability/locality, behind the ISource protocol.
Plug sources as trust-aware value objects: a tools.deps coord classified into a family with its mutability/locality, behind the ISource protocol.
(coord->source coord)ISource value object for a tools.deps coord, or nil for an unknown coord.
ISource value object for a tools.deps coord, or nil for an unknown coord.
(families coord)Coord families a coord map declares — usually one; more than one is ambiguous.
Coord families a coord map declares — usually one; more than one is ambiguous.
(family _)Coord family: :local | :git | :mvn.
Coord family: :local | :git | :mvn.
(local? _)Dev-only filesystem source?
Dev-only filesystem source?
(mutable? _)Can resolve to a different artifact over time?
Can resolve to a different artifact over time?
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |